Crate kcr_infrastructure_cluster_x_k8s_io

Crate kcr_infrastructure_cluster_x_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the infrastructure.cluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

infrastructure.cluster.x-k8s.io/v1alpha1

  • KubevirtCluster
  • KubevirtClusterTemplate
  • KubevirtMachine
  • KubevirtMachineTemplate

infrastructure.cluster.x-k8s.io/v1alpha3

  • VSphereClusterIdentity
  • VSphereCluster
  • VSphereDeploymentZone
  • VSphereFailureDomain
  • VSphereMachine
  • VSphereMachineTemplate
  • VSphereVM

infrastructure.cluster.x-k8s.io/v1alpha4

  • VSphereClusterIdentity
  • VSphereCluster
  • VSphereClusterTemplate
  • VSphereDeploymentZone
  • VSphereFailureDomain
  • VSphereMachine
  • VSphereMachineTemplate
  • VSphereVM

infrastructure.cluster.x-k8s.io/v1beta1

  • IBMPowerVSCluster
  • IBMPowerVSClusterTemplate
  • IBMPowerVSImage
  • IBMPowerVSMachine
  • IBMPowerVSMachineTemplate
  • IBMVPCCluster
  • IBMVPCMachine
  • IBMVPCMachineTemplate
  • VSphereClusterIdentity
  • VSphereCluster
  • VSphereClusterTemplate
  • VSphereDeploymentZone
  • VSphereFailureDomain
  • VSphereMachine
  • VSphereMachineTemplate
  • VSphereVM
  • TinkerbellCluster
  • TinkerbellMachine
  • TinkerbellMachineTemplate

infrastructure.cluster.x-k8s.io/v1beta2

  • IBMPowerVSCluster
  • IBMPowerVSClusterTemplate
  • IBMPowerVSImage
  • IBMPowerVSMachine
  • IBMPowerVSMachineTemplate
  • IBMVPCCluster
  • IBMVPCMachine
  • IBMVPCMachineTemplate
  • VSphereClusterIdentity
  • VSphereCluster
  • VSphereClusterTemplate
  • VSphereDeploymentZone
  • VSphereFailureDomain
  • VSphereMachine
  • VSphereMachineTemplate
  • VSphereVM

Modules

v1alpha1
v1alpha3
v1alpha4
v1beta1
v1beta2