This crate contains kube-rs compatible bindings for Kubernetes custom resources for the infrastructure.cluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
infrastructure.cluster.x-k8s.io/v1alpha1
KubevirtClusterKubevirtClusterTemplateKubevirtMachineKubevirtMachineTemplate
infrastructure.cluster.x-k8s.io/v1alpha3
VSphereClusterIdentityVSphereClusterVSphereDeploymentZoneVSphereFailureDomainVSphereMachineVSphereMachineTemplateVSphereVM
infrastructure.cluster.x-k8s.io/v1alpha4
VSphereClusterIdentityVSphereClusterVSphereClusterTemplateVSphereDeploymentZoneVSphereFailureDomainVSphereMachineVSphereMachineTemplateVSphereVM
infrastructure.cluster.x-k8s.io/v1beta1
IBMPowerVSClusterIBMPowerVSClusterTemplateIBMPowerVSImageIBMPowerVSMachineIBMPowerVSMachineTemplateIBMVPCClusterIBMVPCMachineIBMVPCMachineTemplateVSphereClusterIdentityVSphereClusterVSphereClusterTemplateVSphereDeploymentZoneVSphereFailureDomainVSphereMachineVSphereMachineTemplateVSphereVMTinkerbellClusterTinkerbellMachineTinkerbellMachineTemplate
infrastructure.cluster.x-k8s.io/v1beta2
IBMPowerVSClusterIBMPowerVSClusterTemplateIBMPowerVSImageIBMPowerVSMachineIBMPowerVSMachineTemplateIBMVPCClusterIBMVPCMachineIBMVPCMachineTemplateVSphereClusterIdentityVSphereClusterVSphereClusterTemplateVSphereDeploymentZoneVSphereFailureDomainVSphereMachineVSphereMachineTemplateVSphereVM